#!/bin/bash

ulimit -c 2000000

function run_test()
{
	t=${1}

	echo "Running test [${t}]..."
	(
	cd "${t}"

	# Prepare stuff
	./pre.sh
	if [ "${?}" != "0" ]; then
		echo "Preparation for test [${t}] failed!"
		exit 1
	fi

	if [ -f cmd ]; then
		cmd=`cat cmd`
	else
		cmd="in"
	fi

	valgrind --tool=memcheck \
		--num-callers=16 \
		--leak-check=full \
		--vgdb=no \
		--show-reachable=yes \
		--trace-children=yes \
		--track-origins=yes \
		../../dupdump --verbose --debug --debug --debug --out test.out ${cmd} &>test.log
	sort test.out > test.out2 && mv test.out2 test.out
	diff -u expected test.out > test.diff
	if [ "${?}" != "0" ]; then
		echo "Test [${t}] failed!"
		exit 1
	fi

	rm -f test.out test.diff
	)
}

if [ "${1}" != "" ]; then
	run_test ${1}
else
	find -type d -name 't_*' -print | sort | cut -b3- | while read t; do
		run_test ${t}
	done
fi
